@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display number of todos and more for Thunderbird.
 
@@ -8,7 +7,7 @@ Configuration parameters:
     format_datetime: specify strftime formatting to use (default {})
     format_separator: show separator if more than one (default ' ')
     format_todo: display format for todos
-        (default '\?if=!todo_completed {title}')
+        (default '\\?if=!todo_completed {title}')
     profile: specify a profile path, otherwise first available profile
         eg '~/.thunderbird/abcd1234.default' (default None)
     sort: specify a tuple, eg ('placeholder_name', reverse_boolean)
@@ -54,16 +53,7 @@ format_datetime placeholders:
     SEE EXAMPLE BELOW: "show incompleted titles with last modified time"
 
 Color thresholds:
-    format:
-        todo_total: print a color based on number of total todos
-        todo_completed: print a color based on number of completed todos
-        todo_incompleted: print a color based on number of incompleted todos
-    format_todo:
-        index_total: print a color based on total todo index
-        index_completed: print a color based on completed todo index
-        index_incompleted: print a color based on incompleted todo index
-        flags: print a color based on flags # DISABLED. What is flags?
-        priority: print a color based on number of todo priority
+    xxx: print a color based on the value of `xxx` placeholder
 
 Requires:
     thunderbird: standalone mail and news reader
@@ -77,7 +67,7 @@ thunderbird_todos {
 
 # show rainbow number of incompleted titles
 thunderbird_todos {
-    format = '\?color=todo_incompleted {todo_incompleted} todos'
+    format = '\\?color=todo_incompleted {todo_incompleted} todos'
     thresholds = [
         (1, '#bababa'), (2, '#ffb3ba'), (3, '#ffdfba'), (4, '#ffffba'),
         (5, '#baefba'), (6, '#baffc9'), (7, '#bae1ff'), (8, '#bab3ff')
@@ -86,7 +76,7 @@ thunderbird_todos {
 
 # show rainbow incompleted titles
 thunderbird_todos {
-    format_todo = '\?if=!todo_completed&color=index_incompleted {title}'
+    format_todo = '\\?if=!todo_completed&color=index_incompleted {title}'
     thresholds = [
         (1, '#bababa'), (2, '#ffb3ba'), (3, '#ffdfba'), (4, '#ffffba'),
         (5, '#baefba'), (6, '#baffc9'), (7, '#bae1ff'), (8, '#bab3ff')
@@ -95,9 +85,9 @@ thunderbird_todos {
 
 # show incompleted titles with last modified time
 thunderbird_todos {
-    format_todo = '\?if=!todo_completed {title} {last_modified}'
+    format_todo = '\\?if=!todo_completed {title} {last_modified}'
     format_datetime = {
-        'last_modified': '\?color=degraded last modified %-I:%M%P'
+        'last_modified': '\\?color=degraded last modified %-I:%M%P'
     }
 }
 
@@ -108,24 +98,24 @@ thunderbird_todos {
 
 # show completed titles and incompleted titles
 thunderbird_todos {
-    format_todo = '\?if=todo_completed&color=good {title}|\?color=bad {title}'
+    format_todo = '\\?if=todo_completed&color=good {title}|\\?color=bad {title}'
 }
 
 # make todo blocks
 thunderbird_todos {
     format = 'TODO {format_todo}'
-    format_todo = '\?if=todo_completed&color=good \u25b0|\?color=bad \u25b0'
+    format_todo = '\\?if=todo_completed&color=good \u25b0|\\?color=bad \u25b0'
     format_separator = ''
 }
 
 # display incompleted titles with any priority
 thunderbird_todos {
-    format_todo = '\?if=!todo_completed [\?if=priority>0 {title}]'
+    format_todo = '\\?if=!todo_completed [\\?if=priority>0 {title}]'
 }
 
 # colorize titles based on priorities
 thunderbird_todos {
-    format_todo = '\?if=!todo_completed [\?color=priority {title}]'
+    format_todo = '\\?if=!todo_completed [\\?color=priority {title}]'
     thresholds = [(0, None), (1, 'red'), (5, None), (9, 'deepskyblue')]
 }
 
@@ -148,18 +138,12 @@ SAMPLE OUTPUT
 {'full_text': 'New Task 1, New Task 2'}
 """
 
-from os import path
 from sqlite3 import connect
 from datetime import datetime
+from pathlib import Path
 
 STRING_NO_PROFILE = "missing profile"
 STRING_NOT_INSTALLED = "not installed"
-SUPPORTED_FORMAT_TODO_THRESHOLDS = [
-    "index_total",
-    "index_completed",
-    "index_incompleted",
-    "priority",
-]
 
 
 class Py3status:
@@ -171,7 +155,7 @@ class Py3status:
     format = "{format_todo}"
     format_datetime = {}
     format_separator = " "
-    format_todo = "\?if=!todo_completed {title}"
+    format_todo = r"\?if=!todo_completed {title}"
     profile = None
     sort = ()
     thresholds = []
@@ -182,22 +166,22 @@ class Py3status:
 
         # first profile, please.
         if not self.profile:
-            directory = "~/.thunderbird"
-            profile_ini = path.expanduser(directory + "/profiles.ini")
+            directory = Path("~/.thunderbird").expanduser()
+            profile_ini = directory / "profiles.ini"
             profile = []
-            for line in open(profile_ini):
-                if line.startswith("Path="):
-                    profile.append(
-                        "{}/{}".format(directory, line.split("Path=")[-1].strip())
-                    )
+            with profile_ini.open() as f:
+                for line in f:
+                    if line.startswith("Path="):
+                        profile.append(
+                            "{}/{}".format(directory, line.split("Path=")[-1].strip())
+                        )
             if not len(profile):
                 raise Exception(STRING_NO_PROFILE)
             self.profile = profile[0]
 
-        self.profile = path.expanduser(self.profile)
-        self.path = self.profile + "/calendar-data/local.sqlite"
+        self.profile = Path(self.profile).expanduser()
+        self.path = self.profile / "calendar-data/local.sqlite"
 
-        # convert the datetime?
         self.init_datetimes = []
         for word in self.format_datetime:
             if (self.py3.format_contains(self.format_todo, word)) and (
@@ -205,6 +189,12 @@ class Py3status:
             ):
                 self.init_datetimes.append(word)
 
+        self.thresholds_init = {}
+        for name in ["format", "format_todo"]:
+            self.thresholds_init[name] = self.py3.get_color_names_list(
+                getattr(self, name)
+            )
+
     def _get_thunderbird_todos_data(self):
         connection = connect(self.path)
         cursor = connection.cursor()
@@ -237,7 +227,7 @@ class Py3status:
     def _manipulate(self, data, count):
         new_data = []
         for todo in data:
-            # datetimes?
+            # datetimes
             for k in self.init_datetimes:
                 if k in todo:
                     todo[k] = self.py3.safe_format(
@@ -246,17 +236,16 @@ class Py3status:
                             self.format_datetime[k],
                         )
                     )
-            # use thresholds?
-            if self.thresholds:
-                for x in SUPPORTED_FORMAT_TODO_THRESHOLDS:
-                    if todo[x] is not None:
-                        self.py3.threshold_get_color(todo[x], x)
+            # thresholds
+            for x in self.thresholds_init["format_todo"]:
+                if x in todo:
+                    self.py3.threshold_get_color(todo[x], x)
 
             new_data.append(self.py3.safe_format(self.format_todo, todo))
 
-        if self.thresholds:
-            for k, v in count.items():
-                self.py3.threshold_get_color(v, k)
+        for x in self.thresholds_init["format"]:
+            if x in count:
+                self.py3.threshold_get_color(count[x], x)
 
         format_separator = self.py3.safe_format(self.format_separator)
         format_todo = self.py3.composite_join(format_separator, new_data)
